pub struct StaticKeyExchange { /* private fields */ }Expand description
X25519 key exchange with a static (reusable) secret
Unlike KeyExchange which uses ephemeral secrets that can only be used once,
this struct uses a static secret that can be reused for multiple key derivations.
Implementations
Sourceimpl StaticKeyExchange
impl StaticKeyExchange
Sourcepub fn from_secret(secret_bytes: [u8; 32]) -> Self
pub fn from_secret(secret_bytes: [u8; 32]) -> Self
Create from existing secret bytes
Sourcepub fn public_key_bytes(&self) -> [u8; 32]
pub fn public_key_bytes(&self) -> [u8; 32]
Get our public key bytes
Sourcepub fn public_key_base64(&self) -> String
pub fn public_key_base64(&self) -> String
Get our public key as base64
Derive shared secret from peer’s public key This can be called multiple times (unlike ephemeral key exchange)