pub struct CreateDatabaseRequest {
pub name: String,
pub create_in_parent_id: String,
pub encrypted: bool,
pub read_audit: bool,
pub write_audit: bool,
pub discoverable: i32,
pub alias: Vec<String>,
pub description: String,
}Fields
name: StringThe name of the database to create.
create_in_parent_id: StringOptional - the id of the folder resource in which to create the database. If omitted, the callers home folder is used.
encrypted: boolSet to encrypt the database. The encryption key will be generated by the server, the internal Volt server uses the root volt key.
read_audit: boolSet to audit all SELECT database operations.
write_audit: boolSet to audit all INSERT, UPDATE, and DELETE database operations.
discoverable: i32The discovery mode of the underlying Volt resource.
alias: Vec<String>Alias(es) that can be used to refer to the database rather than the id. Each alias must be unique to the Volt, this is enforced by the API. No format restrictions are currently applied to alias, but this may change in future, for the time being it makes sense to stick to alphanumeric characters and ‘_’ or ‘-’.
description: StringOptional description of the database.
Implementations
Sourceimpl CreateDatabaseRequest
impl CreateDatabaseRequest
Sourcepub fn discoverable(&self) -> DiscoveryMode
pub fn discoverable(&self) -> DiscoveryMode
Returns the enum value of discoverable, or the default if the field is set to an invalid enum value.
Sourcepub fn set_discoverable(&mut self, value: DiscoveryMode)
pub fn set_discoverable(&mut self, value: DiscoveryMode)
Sets discoverable to the provided enum value.